# New in 0.14.2 (2021-10-18)

Bug fix and new tutorial.

## Changes

-   Bug fix in {class}`~scvi.external.RNAStereoscope` where loss was computed with mean for a minibatch instead of sum. This ensures reproducibility with the original implementation ([#1228]).
-   New Cell2location contributed tutorial ([#1232]).

## Contributors

-   [@adamgayoso]
-   [@jjhong922]
-   [@vitkl]
-   [@watiss]

[#1228]: https://github.com/YosefLab/scvi-tools/pull/1228
[#1232]: https://github.com/YosefLab/scvi-tools/pull/1232
[@adamgayoso]: https://github.com/adamgayoso
[@jjhong922]: https://github.com/jjhong922
[@vitkl]: https://github.com/vitkl
[@watiss]: https://github.com/watiss
